# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/adapter_service.proto',
  package='adapter_service',
  syntax='proto3',
  serialized_options=b'\n#org.opencord.voltha.adapter_serviceB\024VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_service',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#voltha_protos/adapter_service.proto\x12\x0f\x61\x64\x61pter_service\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1avoltha_protos/health.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1dvoltha_protos/omci_test.proto\x1a\x1avoltha_protos/events.proto2\x94\x13\n\x0e\x41\x64\x61pterService\x12;\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus\x12\x35\n\x0b\x41\x64optDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0fReconcileDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65leteDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x37\n\rDisableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eReEnableDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0cRebootDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eSelfTestDevice\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x42\n\x10GetOfpDeviceInfo\x12\x0e.device.Device\x1a\x1e.core_adapter.SwitchCapability\x12\x39\n\x0f\x43hildDeviceLost\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x32\n\nEnablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x33\n\x0b\x44isablePort\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fUpdateFlowsBulk\x12\x17.core_adapter.BulkFlows\x1a\x16.google.protobuf.Empty\x12R\n\x18UpdateFlowsIncrementally\x12\x1e.core_adapter.IncrementalFlows\x1a\x16.google.protobuf.Empty\x12@\n\rSendPacketOut\x12\x17.core_adapter.PacketOut\x1a\x16.google.protobuf.Empty\x12\x45\n\x0eUpdatePmConfig\x12\x1b.core_adapter.PmConfigsInfo\x1a\x16.google.protobuf.Empty\x12S\n\x10\x44ownloadOnuImage\x12\".device.DeviceImageDownloadRequest\x1a\x1b.device.DeviceImageResponse\x12L\n\x11GetOnuImageStatus\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\x14\x41\x62ortOnuImageUpgrade\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12-\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.device.OnuImages\x12K\n\x10\x41\x63tivateOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12I\n\x0e\x43ommitOnuImage\x12\x1a.device.DeviceImageRequest\x1a\x1b.device.DeviceImageResponse\x12O\n\rDownloadImage\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12X\n\x16GetImageDownloadStatus\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x43\x61ncelImageDownload\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12U\n\x13\x41\x63tivateImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12S\n\x11RevertImageUpdate\x12\".core_adapter.ImageDownloadMessage\x1a\x15.device.ImageDownload\"\x03\x88\x02\x01\x12;\n\rStartOmciTest\x12\x16.core_adapter.OMCITest\x1a\x12.omci.TestResponse\x12J\n\rSimulateAlarm\x12\".core_adapter.SimulateAlarmMessage\x1a\x15.common.OperationResp\x12;\n\rSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12=\n\x0fUnSuppressEvent\x12\x12.event.EventFilter\x1a\x16.google.protobuf.Empty\x12H\n\x0bGetExtValue\x12 .core_adapter.GetExtValueMessage\x1a\x17.extension.ReturnValues\x12G\n\x0bSetExtValue\x12 .core_adapter.SetExtValueMessage\x1a\x16.google.protobuf.Empty\x12U\n\x0eGetSingleValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12U\n\x0eSetSingleValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponseBt\n#org.opencord.voltha.adapter_serviceB\x14VolthaAdapterServiceZ7github.com/opencord/voltha-protos/v5/go/adapter_serviceb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_core__adapter__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_extensions__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,voltha__protos_dot_omci__test__pb2.DESCRIPTOR,voltha__protos_dot_events__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_ADAPTERSERVICE = _descriptor.ServiceDescriptor(
  name='AdapterService',
  full_name='adapter_service.AdapterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=323,
  serialized_end=2775,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='adapter_service.AdapterService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._CONNECTION,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AdoptDevice',
    full_name='adapter_service.AdapterService.AdoptDevice',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileDevice',
    full_name='adapter_service.AdapterService.ReconcileDevice',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDevice',
    full_name='adapter_service.AdapterService.DeleteDevice',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableDevice',
    full_name='adapter_service.AdapterService.DisableDevice',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReEnableDevice',
    full_name='adapter_service.AdapterService.ReEnableDevice',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebootDevice',
    full_name='adapter_service.AdapterService.RebootDevice',
    index=6,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SelfTestDevice',
    full_name='adapter_service.AdapterService.SelfTestDevice',
    index=7,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOfpDeviceInfo',
    full_name='adapter_service.AdapterService.GetOfpDeviceInfo',
    index=8,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=voltha__protos_dot_core__adapter__pb2._SWITCHCAPABILITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDeviceLost',
    full_name='adapter_service.AdapterService.ChildDeviceLost',
    index=9,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnablePort',
    full_name='adapter_service.AdapterService.EnablePort',
    index=10,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisablePort',
    full_name='adapter_service.AdapterService.DisablePort',
    index=11,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowsBulk',
    full_name='adapter_service.AdapterService.UpdateFlowsBulk',
    index=12,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._BULKFLOWS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowsIncrementally',
    full_name='adapter_service.AdapterService.UpdateFlowsIncrementally',
    index=13,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._INCREMENTALFLOWS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPacketOut',
    full_name='adapter_service.AdapterService.SendPacketOut',
    index=14,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PACKETOUT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePmConfig',
    full_name='adapter_service.AdapterService.UpdatePmConfig',
    index=15,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._PMCONFIGSINFO,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadOnuImage',
    full_name='adapter_service.AdapterService.DownloadOnuImage',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEDOWNLOADREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnuImageStatus',
    full_name='adapter_service.AdapterService.GetOnuImageStatus',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortOnuImageUpgrade',
    full_name='adapter_service.AdapterService.AbortOnuImageUpgrade',
    index=18,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnuImages',
    full_name='adapter_service.AdapterService.GetOnuImages',
    index=19,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._ONUIMAGES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateOnuImage',
    full_name='adapter_service.AdapterService.ActivateOnuImage',
    index=20,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CommitOnuImage',
    full_name='adapter_service.AdapterService.CommitOnuImage',
    index=21,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_device__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadImage',
    full_name='adapter_service.AdapterService.DownloadImage',
    index=22,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageDownloadStatus',
    full_name='adapter_service.AdapterService.GetImageDownloadStatus',
    index=23,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelImageDownload',
    full_name='adapter_service.AdapterService.CancelImageDownload',
    index=24,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateImageUpdate',
    full_name='adapter_service.AdapterService.ActivateImageUpdate',
    index=25,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevertImageUpdate',
    full_name='adapter_service.AdapterService.RevertImageUpdate',
    index=26,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartOmciTest',
    full_name='adapter_service.AdapterService.StartOmciTest',
    index=27,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._OMCITEST,
    output_type=voltha__protos_dot_omci__test__pb2._TESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SimulateAlarm',
    full_name='adapter_service.AdapterService.SimulateAlarm',
    index=28,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._SIMULATEALARMMESSAGE,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SuppressEvent',
    full_name='adapter_service.AdapterService.SuppressEvent',
    index=29,
    containing_service=None,
    input_type=voltha__protos_dot_events__pb2._EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnSuppressEvent',
    full_name='adapter_service.AdapterService.UnSuppressEvent',
    index=30,
    containing_service=None,
    input_type=voltha__protos_dot_events__pb2._EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='adapter_service.AdapterService.GetExtValue',
    index=31,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._GETEXTVALUEMESSAGE,
    output_type=voltha__protos_dot_extensions__pb2._RETURNVALUES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExtValue',
    full_name='adapter_service.AdapterService.SetExtValue',
    index=32,
    containing_service=None,
    input_type=voltha__protos_dot_core__adapter__pb2._SETEXTVALUEMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSingleValue',
    full_name='adapter_service.AdapterService.GetSingleValue',
    index=33,
    containing_service=None,
    input_type=voltha__protos_dot_extensions__pb2._SINGLEGETVALUEREQUEST,
    output_type=voltha__protos_dot_extensions__pb2._SINGLEGETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSingleValue',
    full_name='adapter_service.AdapterService.SetSingleValue',
    index=34,
    containing_service=None,
    input_type=voltha__protos_dot_extensions__pb2._SINGLESETVALUEREQUEST,
    output_type=voltha__protos_dot_extensions__pb2._SINGLESETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADAPTERSERVICE)

DESCRIPTOR.services_by_name['AdapterService'] = _ADAPTERSERVICE

# @@protoc_insertion_point(module_scope)
